@@ -161,6 +161,8 @@ class Query(object):
         for filter_statement in self.filters:
 
             print(isinstance(filter_statement.value, str))
+            print(isinstance(filter_statement.value, basestring))
+            print(type(filter_statement.value, str))
 
             if isinstance(filter_statement.value, str):
                 query_data += ' FILTER %s.%s %s "%s"' % (
